@@ -60,6 +60,7 @@ def check_is_site(string):
     sf = hostnames.get('sf')
     by = hostnames.get('by')
     fx = hostnames.get('fx')
+    hw = hostnames.get('hw')
     nk = hostnames.get('nk')
     ww = hostnames.get('ww')
 
@@ -73,6 +74,8 @@ def check_is_site(string):
         return "BY"
     elif fx and fx.split('.')[0] in string:
         return "FX"
+    elif hw and hw.split('.')[0] in string:
+        return "HW"
     elif nk and nk.split('.')[0] in string:
         return "NK"
     elif ww and ww.split('.')[0] in string:
@@ -149,7 +152,8 @@ def check_valid_release(title, retail_only, hevc_retail):
     bluray_tags = [".bd-rip.", ".br-rip.", ".bdrip.", "brrip", ".bluray-rip.", ".bluray.", ".bd-disk.", ".bd.", ".bd5.",
                    ".bd9.", ".bd25.", ".bd50."]
     web_tags = [".web.", ".web-rip.", ".webrip.", ".vod-rip.", ".webdl.", ".web-dl.", ".ddc.", ".webhd.", ".web-hd.",
-                ".amazonhd.", ".amazonuhd.", ".webuhd.", ".amazonhd.", ".amazonuhd.", ".ituneshd.", ".itunesuhd."]
+                ".amazonhd.", ".amazonuhd.", ".webuhd.", ".amazonhd.", ".amazonuhd.", ".ituneshd.", ".itunesuhd.",
+                ".hbomaxhd.", ".hbomaxuhd."]
     trash_tags = [".cam.", ".cam-rip.", ".ts.", ".telesync.", ".wp.", ".workprint.", ".tc.", ".telecine.", ".vhs-rip.",
                   ".tv-rip.", ".hdtv-rip.", ".hdtv.", ".tvrip.", ".hdtvrip.", ".sat-rip.", ".dvb-rip.", ".ds-rip.",
                   ".scr.", ".screener.", ".dvdscr.", ".dvdscreener.", ".bdscr.", ".r5.", ".dvdrip.", ".dvd."]
@@ -256,7 +260,7 @@ def get_to_decrypt():
             fx = CrawlerConfig('Hostnames').get('fx')
             ww = CrawlerConfig('Hostnames').get('ww')
             for package in to_decrypt:
-                if not "filecrypt." in package[1] and not fx in package[1]:
+                if not "filecrypt." in package[1] and not fx in package[1] and not ww in package[1]:
                     easy_decrypt_exists = True
 
             packages = []
